@@ -2,7 +2,7 @@ from pathlib import Path
 import click
 import collections
 from librelingo_yaml_loader import load_course
-from .export import export_course
+from librelingo_json_export.export import export_course
 
 
 Settings = collections.namedtuple("Settings", [
